package com.trade.client.accounts.receivepayment.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.trade.client.accounts.receivepayment.vo.ReceivePaymentDetailVo;
import com.trade.client.enterprise.customer.domain.CustomerUser;
import com.trade.client.enterprise.customer.service.CustomerUserService;
import com.trade.common.exception.ServiceException;
import com.trade.common.utils.ConstantUtil;
import com.trade.common.utils.LoggerUtil;
import com.trade.service.finance.disbursement.domain.BillingDisbursement;
import com.trade.service.finance.disbursement.dto.ReceivePaymentSearchDto;
import com.trade.client.accounts.receivepayment.service.ReceivePaymentService;
import com.trade.service.finance.disbursement.vo.ReceivePaymentPageVo;
import com.trade.common.core.page.GridPage;
import com.trade.service.finance.disbursement.service.BillingDisbursementService;
import com.trade.service.trade.salescontract.domain.ContractTerms;
import com.trade.service.trade.salescontract.domain.SalesContract;
import com.trade.service.trade.salescontract.service.ContractTermsService;
import com.trade.service.trade.salescontract.service.SalesContractService;
import org.slf4j.Logger;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * @description: 收款服务实现类
 * @Author: wanglang
 * @Date: 2024/10/31
 * @Version: 1.0
 */
@Service
public class ReceivePaymentServiceImpl implements ReceivePaymentService {

    private static final Logger log = LoggerUtil.logger(LoggerUtil.LogFileNameEnum.SERVICES_LOG);;
    @Resource
    private BillingDisbursementService billingDisbursementService;
    @Resource
    private CustomerUserService customerUserService;
    @Resource
    private SalesContractService salesContractService;
    @Resource
    private ContractTermsService contractTermsService;

    @Override
    public GridPage<ReceivePaymentPageVo> queryListByPage(ReceivePaymentSearchDto searchDto) {
        CustomerUser customerUser = customerUserService.getCustomerUser();
        searchDto.setCustomerUserId(customerUser.getId());
        Page<ReceivePaymentPageVo> page = PageHelper.startPage(searchDto.getPage(), searchDto.getRows());
        List<ReceivePaymentPageVo> voList = billingDisbursementService.queryPageForCustomer(searchDto);
        return new GridPage<>(searchDto.getPage(), searchDto.getRows(), page.getTotal(), voList);
    }

    @Override
    public ReceivePaymentDetailVo queryDetailById(Long id) {
        BillingDisbursement billingDisbursement = billingDisbursementService.getById(id);
        if (billingDisbursement == null) {
            throw new ServiceException("收款记录数据不存在");
        }
        ReceivePaymentDetailVo vo = new ReceivePaymentDetailVo();
        vo.setBillingDisbursement(billingDisbursement);
        SalesContract salesContract = salesContractService.getByContractNo(billingDisbursement.getSalesContractNo(),
                billingDisbursement.getCustomerUserId());
        if (salesContract == null) {
            log.error("销售合同不存在,销售合同编号:{}", billingDisbursement.getSalesContractNo());
            return vo;
        }
        ContractTerms contractTerms = contractTermsService.getByContractIdAndType(salesContract.getId(),
                ConstantUtil.SALES_CONTRACT_NO_PREFIX);
        if (contractTerms == null) {
            log.error("销售合同条款不存在,销售合同编号:{}", billingDisbursement.getSalesContractNo());
            return vo;
        }
        vo.setAccountNumber(contractTerms.getAccountNumber());
        vo.setAccountName(contractTerms.getAccountName());
        vo.setOpeningBank(contractTerms.getOpeningBank());
        // 单据处理

        return vo;
    }
}
